==> jc-1.4.0.tar.gz: javax/swing/plaf/basic/BasicInternalFrameUI__24ComponentHandler.h <==
// public class javax.swing.plaf.basic.BasicInternalFrameUI$ComponentHandler

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 6051d559141ca5cc javax_swing_plaf_basic_BasicInternalFrameUI__24ComponentHandler

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_swing_plaf_basic_BasicInternalFrameUI__24ComponentHandler_H_
#define _JC_javax_swing_plaf_basic_BasicInternalFrameUI__24ComponentHandler_H_

// Forward structure declarations
struct _jc_java_awt_event_ComponentEvent$object;
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_plaf_basic_BasicInternalFrameUI$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24ComponentHandler$sub_refs	_jc_javax_swing_plaf_basic_BasicInternalFrameUI__24ComponentHandler$sub_refs;
typedef struct _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24ComponentHandler$sub_nonrefs	_jc_javax_swing_plaf_basic_BasicInternalFrameUI__24ComponentHandler$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24ComponentHandler$refs	_jc_javax_swing_plaf_basic_BasicInternalFrameUI__24ComponentHandler$refs;
typedef struct _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24ComponentHandler$nonrefs	_jc_javax_swing_plaf_basic_BasicInternalFrameUI__24ComponentHandler$nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24ComponentHandler$object	_jc_javax_swing_plaf_basic_BasicInternalFrameUI__24ComponentHandler$object;

typedef const struct _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24ComponentHandler$vmethods	_jc_javax_swing_plaf_basic_BasicInternalFrameUI__24ComponentHandler$vmethods;
typedef const struct _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24ComponentHandler$vtable	_jc_javax_swing_plaf_basic_BasicInternalFrameUI__24ComponentHandler$vtable;
typedef const struct _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24ComponentHandler$vtype	_jc_javax_swing_plaf_basic_BasicInternalFrameUI__24ComponentHandler$vtype;

// Constructors
extern void _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24ComponentHandler$method$_init$05643df5b45f5094(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24ComponentHandler$object *, struct _jc_javax_swing_plaf_basic_BasicInternalFrameUI$object *);

// Virtual methods
extern void _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24ComponentHandler$method$componentHidden$c45a3d9480cd8f67(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24ComponentHandler$object *, struct _jc_java_awt_event_ComponentEvent$object *);
extern void _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24ComponentHandler$method$componentMoved$81a358183048de7c(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24ComponentHandler$object *, struct _jc_java_awt_event_ComponentEvent$object *);
extern void _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24ComponentHandler$method$componentResized$ac5fcd90b88c07ec(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24ComponentHandler$object *, struct _jc_java_awt_event_ComponentEvent$object *);
extern void _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24ComponentHandler$method$componentShown$f9db658060a8b292(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24ComponentHandler$object *, struct _jc_java_awt_event_ComponentEvent$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24ComponentHandler$method_info$componentHidden$c45a3d9480cd8f67;
extern _jc_method _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24ComponentHandler$method_info$componentMoved$81a358183048de7c;
extern _jc_method _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24ComponentHandler$method_info$componentResized$ac5fcd90b88c07ec;
extern _jc_method _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24ComponentHandler$method_info$componentShown$f9db658060a8b292;

// Virtual methods structure
struct _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24ComponentHandler$vmethods {
	void	(*componentHidden$c45a3d9480cd8f67)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24ComponentHandler$object *, struct _jc_java_awt_event_ComponentEvent$object *);
	void	(*componentMoved$81a358183048de7c)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24ComponentHandler$object *, struct _jc_java_awt_event_ComponentEvent$object *);
	void	(*componentResized$ac5fcd90b88c07ec)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24ComponentHandler$object *, struct _jc_java_awt_event_ComponentEvent$object *);
	void	(*componentShown$f9db658060a8b292)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24ComponentHandler$object *, struct _jc_java_awt_event_ComponentEvent$object *);
};

// Vtable
struct _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24ComponentHandler$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_plaf_basic_BasicInternalFrameUI__24ComponentHandler$vmethods	javax_swing_plaf_basic_BasicInternalFrameUI__24ComponentHandler;
};

// Vtype
struct _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24ComponentHandler$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_basic_BasicInternalFrameUI__24ComponentHandler$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24ComponentHandler$sub_refs {
	struct _jc_javax_swing_plaf_basic_BasicInternalFrameUI$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24ComponentHandler$refs {
    _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24ComponentHandler$sub_refs	javax_swing_plaf_basic_BasicInternalFrameUI__24ComponentHandler;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24ComponentHandler$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24ComponentHandler$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24ComponentHandler$sub_nonrefs	javax_swing_plaf_basic_BasicInternalFrameUI__24ComponentHandler;
};

// Object instance structure
struct _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24ComponentHandler$object {
	_jc_javax_swing_plaf_basic_BasicInternalFrameUI__24ComponentHandler$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_basic_BasicInternalFrameUI__24ComponentHandler$vtype	*vtype;
	_jc_javax_swing_plaf_basic_BasicInternalFrameUI__24ComponentHandler$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24ComponentHandler$vtype _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24ComponentHandler$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_basic_BasicInternalFrameUI__24ComponentHandler, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24ComponentHandler$class_object;

#endif	/* _JC_javax_swing_plaf_basic_BasicInternalFrameUI__24ComponentHandler_H_ */

==> jc-1.4.5.tar.gz: javax/swing/plaf/basic/BasicInternalFrameUI__24ComponentHandler.h <==
// public class javax.swing.plaf.basic.BasicInternalFrameUI$ComponentHandler

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 6051d559141ca5cc javax_swing_plaf_basic_BasicInternalFrameUI__24ComponentHandler

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_swing_plaf_basic_BasicInternalFrameUI__24ComponentHandler_H_
#define _JC_javax_swing_plaf_basic_BasicInternalFrameUI__24ComponentHandler_H_

// Forward structure declarations
struct _jc_java_awt_event_ComponentEvent$object;
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_plaf_basic_BasicInternalFrameUI$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24ComponentHandler$sub_refs	_jc_javax_swing_plaf_basic_BasicInternalFrameUI__24ComponentHandler$sub_refs;
typedef struct _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24ComponentHandler$sub_nonrefs	_jc_javax_swing_plaf_basic_BasicInternalFrameUI__24ComponentHandler$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24ComponentHandler$refs	_jc_javax_swing_plaf_basic_BasicInternalFrameUI__24ComponentHandler$refs;
typedef struct _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24ComponentHandler$nonrefs	_jc_javax_swing_plaf_basic_BasicInternalFrameUI__24ComponentHandler$nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24ComponentHandler$object	_jc_javax_swing_plaf_basic_BasicInternalFrameUI__24ComponentHandler$object;

typedef const struct _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24ComponentHandler$vmethods	_jc_javax_swing_plaf_basic_BasicInternalFrameUI__24ComponentHandler$vmethods;
typedef const struct _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24ComponentHandler$vtable	_jc_javax_swing_plaf_basic_BasicInternalFrameUI__24ComponentHandler$vtable;
typedef const struct _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24ComponentHandler$vtype	_jc_javax_swing_plaf_basic_BasicInternalFrameUI__24ComponentHandler$vtype;

// Constructors
extern void _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24ComponentHandler$method$_init$05643df5b45f5094(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24ComponentHandler$object *, struct _jc_javax_swing_plaf_basic_BasicInternalFrameUI$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24ComponentHandler$method$componentHidden$c45a3d9480cd8f67(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24ComponentHandler$object *, struct _jc_java_awt_event_ComponentEvent$object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24ComponentHandler$method$componentMoved$81a358183048de7c(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24ComponentHandler$object *, struct _jc_java_awt_event_ComponentEvent$object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24ComponentHandler$method$componentResized$ac5fcd90b88c07ec(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24ComponentHandler$object *, struct _jc_java_awt_event_ComponentEvent$object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24ComponentHandler$method$componentShown$f9db658060a8b292(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24ComponentHandler$object *, struct _jc_java_awt_event_ComponentEvent$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24ComponentHandler$method_info$componentHidden$c45a3d9480cd8f67;
extern _jc_method _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24ComponentHandler$method_info$componentMoved$81a358183048de7c;
extern _jc_method _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24ComponentHandler$method_info$componentResized$ac5fcd90b88c07ec;
extern _jc_method _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24ComponentHandler$method_info$componentShown$f9db658060a8b292;

// Virtual methods structure
struct _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24ComponentHandler$vmethods {
	void	(*componentHidden$c45a3d9480cd8f67)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24ComponentHandler$object *, struct _jc_java_awt_event_ComponentEvent$object *) _JC_JCNI_ATTR;
	void	(*componentMoved$81a358183048de7c)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24ComponentHandler$object *, struct _jc_java_awt_event_ComponentEvent$object *) _JC_JCNI_ATTR;
	void	(*componentResized$ac5fcd90b88c07ec)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24ComponentHandler$object *, struct _jc_java_awt_event_ComponentEvent$object *) _JC_JCNI_ATTR;
	void	(*componentShown$f9db658060a8b292)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24ComponentHandler$object *, struct _jc_java_awt_event_ComponentEvent$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24ComponentHandler$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_plaf_basic_BasicInternalFrameUI__24ComponentHandler$vmethods	javax_swing_plaf_basic_BasicInternalFrameUI__24ComponentHandler;
};

// Vtype
struct _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24ComponentHandler$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_basic_BasicInternalFrameUI__24ComponentHandler$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24ComponentHandler$sub_refs {
	struct _jc_javax_swing_plaf_basic_BasicInternalFrameUI$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24ComponentHandler$refs {
    _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24ComponentHandler$sub_refs	javax_swing_plaf_basic_BasicInternalFrameUI__24ComponentHandler;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24ComponentHandler$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24ComponentHandler$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24ComponentHandler$sub_nonrefs	javax_swing_plaf_basic_BasicInternalFrameUI__24ComponentHandler;
};

// Object instance structure
struct _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24ComponentHandler$object {
	_jc_javax_swing_plaf_basic_BasicInternalFrameUI__24ComponentHandler$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_basic_BasicInternalFrameUI__24ComponentHandler$vtype	*vtype;
	_jc_javax_swing_plaf_basic_BasicInternalFrameUI__24ComponentHandler$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24ComponentHandler$vtype _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24ComponentHandler$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_basic_BasicInternalFrameUI__24ComponentHandler, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_basic_BasicInternalFrameUI__24ComponentHandler$class_object;

#endif	/* _JC_javax_swing_plaf_basic_BasicInternalFrameUI__24ComponentHandler_H_ */
